@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 from trdb2py.config import loadConfig
 from trdb2py.indicator import isPriceIndicator, isNeedSecondY
-from trdb2py.trdb2 import simTradings, getAssetCandles, simTrading, getAssetCandles2
+from trdb2py.trdb2 import (simTradings, getAssetCandles, simTrading, getAssetCandles2, simTradings3)
 from trdb2py.utils import str2asset, nextWeekDay, asset2str
 from trdb2py.timeutils import str2timestamp, getDayInYear, getYearDays, calcYears
 from trdb2py.pdutils import (buildPNLReport, getPNLLastTs, getPNLValueWithTimestamp, mergePNL, mergePNLEx,
